.rendered_html a {
  text-decoration: inherit !important;
}

.rendered_html :link {
  text-decoration: inherit !important;
}

.rendered_html :visited {
  text-decoration: inherit !important;
}

pre code {
  background-color: inherit !important;
}

.md-content a.md-icon.md-content__icon:first-child {
  display: none;
}

.rendered_html h1:first-child {
  margin-top: 0;
}

.highlight {
  color: #000000;
}

.highlight code {
  color: #000000;
}

.highlight .n {
  color: #333333;
}

.highlight .p {
  color: #000000;
}

.text_cell .prompt {
  display: none !important;
}

div.input_prompt {
  padding: 0.2em 0.4em;
}

div.output_prompt {
  padding: 0.4em;
}

.text_cell {
  margin: 0 !important;
  padding: 0 !important;
  border: none !important;
}

.text_cell_render {
  margin: 0 !important;
  padding: 0 !important;
  border: none !important;
}

.rendered_html * + p {
  margin-top: inherit !important;
}

.anchor-link {
  display: none !important;
}

.code_cell {
  margin: 0 !important;
  padding: 5px 0 !important;
  border: none !important;
}

.celltoolbar {
  border: thin solid #CFCFCF;
  border-bottom: none;
  background: #EEE;
  border-radius: 2px 2px 0px 0px;
  width: 100%;
  height: 29px;
  padding-right: 4px;
  box-orient: horizontal;
  box-align: stretch;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  -webkit-box-align: stretch;
      -ms-flex-align: stretch;
          align-items: stretch;
  box-pack: end;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
  display: -webkit-flex;
}

.celltoolbar .tags_button_container {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
}

.celltoolbar .tags_button_container .tag-container {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  overflow: hidden;
  position: relative;
}

.celltoolbar .tags_button_container .tag-container .cell-tag {
  background-color: #fff;
  white-space: nowrap;
  margin: 3px 4px;
  padding: 0 4px;
  border-radius: 1px;
  border: 1px solid #ccc;
  -webkit-box-shadow: none;
          box-shadow: none;
  width: inherit;
  font-size: 13px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  height: 22px;
  line-height: 22px;
  display: inline-block;
}

div.input_area > div.highlight {
  margin: 0.25em 0.4em !important;
}

.code_cell pre {
  font-size: 12px !important;
}

.output_html table.dataframe {
  font-family: Arial, sans-serif;
  font-size: 13px;
  line-height: 20px;
}

.output_html table.dataframe th, td {
  padding: 4px;
  text-align: left;
}

.bk-plot-wrapper tbody tr {
  background: none !important;
}

.bk-plot-wrapper tbody tr:hover {
  background: none !important;
}
