GENERATED_MD = """
<div class="notebook-content">
{html}
</div>
"""

LATEX_CUSTOM_SCRIPT = """
<script type="text/javascript">if (!document.getElementById("mathjaxscript_pelican_#%@#$@#")) {
    var mathjaxscript = document.createElement("script");
    mathjaxscript.id = "mathjaxscript_pelican_#%@#$@#";
    mathjaxscript.type = "text/javascript";
    mathjaxscript.src = "//cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.1/MathJax.js?config=TeX-AMS-MML_HTMLorMML";
    mathjaxscript[(window.opera ? "innerHTML" : "text")] =
        "MathJax.Hub.Config({" +
        "    config: ['MMLorHTML.js']," +
        "    TeX: { extensions: ['AMSmath.js', 'AMSsymbols.js', 'noErrors.js', 'noUndefined.js'], equationNumbers: { autoNumber: 'AMS' } }," +
        "    jax: ['input/TeX', 'input/MathML', 'output/HTML-CSS']," +
        "    extensions: ['tex2jax.js', 'mml2jax.js', 'MathMenu.js', 'MathZoom.js']," +
        "    displayAlign: 'center'," +
        "    displayIndent: '0em'," +
        "    showMathMenu: true," +
        "    tex2jax: { " +
        "        inlineMath: [ ['$', '$'] ], " +
        "        displayMath: [ ['$$', '$$'] ]," +
        "        processEscapes: true," +
        "        preview: 'TeX'," +
        "    }, " +
        "    'HTML-CSS': { " +
        " linebreaks: { automatic: true, width: '95% container' }, " +
        "        styles: { '.MathJax_Display, .MathJax .mo, .MathJax .mi, .MathJax .mn': {color: 'black ! important'} }" +
        "    } " +
        "}); ";
    (document.body || document.getElementsByTagName("head")[0]).appendChild(mathjaxscript);
}
</script>
"""
